rpms/kdelibs/F-10 kdelibs-4.1.70-cmake.patch, NONE, 1.1 kdelibs-4.1.72-kstandarddirs.patch, NONE, 1.1 kdelibs-4.1.72-no-cache-kdeglobals-paths.patch, NONE, 1.1 kdelibs-4.1.72-policykit-workaround.patch, NONE, 1.1 kdelibs-4.1.82-kde149705.patch, NONE, 1.1 kdelibs-4.1.96-AllowExternalPaths.patch, NONE, 1.1 kdelibs-4.1.96-cmake.patch, NONE, 1.1 kdelibs-4.1.96-parallel_devel.patch, NONE, 1.1 .cvsignore, 1.61, 1.62 kde4.csh, 1.2, 1.3 kde4.sh, 1.2, 1.3 kdelibs.spec, 1.395, 1.396 sources, 1.73, 1.74 kdelibs-3.95.0-kde149705.patch, 1.1, NONE kdelibs-4.0.2-no-cache-kdeglobals-paths.patch, 1.1, NONE kdelibs-4.1.0-kstandarddirs.patch, 1.1, NONE kdelibs-4.1.0-parallel_devel.patch, 1.1, NONE kdelibs-4.1.1-cmake.patch, 1.2, NONE kdelibs-4.1.4-policykit-workaround.patch, 1.2, NONE

Rex Dieter rdieter at fedoraproject.org
Fri Jan 23 18:59:58 UTC 2009


Author: rdieter

Update of /cvs/pkgs/rpms/kdelibs/F-10
In directory cvs1.fedora.phx.redhat.com:/tmp/cvs-serv12302

Modified Files:
	.cvsignore kde4.csh kde4.sh kdelibs.spec sources 
Added Files:
	kdelibs-4.1.70-cmake.patch kdelibs-4.1.72-kstandarddirs.patch 
	kdelibs-4.1.72-no-cache-kdeglobals-paths.patch 
	kdelibs-4.1.72-policykit-workaround.patch 
	kdelibs-4.1.82-kde149705.patch 
	kdelibs-4.1.96-AllowExternalPaths.patch 
	kdelibs-4.1.96-cmake.patch kdelibs-4.1.96-parallel_devel.patch 
Removed Files:
	kdelibs-3.95.0-kde149705.patch 
	kdelibs-4.0.2-no-cache-kdeglobals-paths.patch 
	kdelibs-4.1.0-kstandarddirs.patch 
	kdelibs-4.1.0-parallel_devel.patch kdelibs-4.1.1-cmake.patch 
	kdelibs-4.1.4-policykit-workaround.patch 
Log Message:
sync with devel/ for 4.2.0 hotness


kdelibs-4.1.70-cmake.patch:

--- NEW FILE kdelibs-4.1.70-cmake.patch ---
diff -Naur kdelibs-4.1.70/cmake/modules/FindKDE4Internal.cmake kdelibs-4.1.70.cmake/cmake/modules/FindKDE4Internal.cmake
--- kdelibs-4.1.70/cmake/modules/FindKDE4Internal.cmake	2008-10-19 16:56:45.000000000 +0200
+++ kdelibs-4.1.70.cmake/cmake/modules/FindKDE4Internal.cmake	2008-10-19 17:06:14.000000000 +0200
@@ -817,6 +817,7 @@
 # CMake generators if no build type is set.
 if (NOT CMAKE_CONFIGURATION_TYPES AND NOT CMAKE_BUILD_TYPE)
    set(CMAKE_BUILD_TYPE RelWithDebInfo)
+   set(CMAKE_CONFIGURATION_TYPES ${CMAKE_BUILD_TYPE})
 endif (NOT CMAKE_CONFIGURATION_TYPES AND NOT CMAKE_BUILD_TYPE)
 
 

kdelibs-4.1.72-kstandarddirs.patch:

--- NEW FILE kdelibs-4.1.72-kstandarddirs.patch ---
diff -Naur kdelibs-4.1.72/kdecore/kernel/kstandarddirs.cpp kdelibs-4.1.72.kstandarddirs/kdecore/kernel/kstandarddirs.cpp
--- kdelibs-4.1.72/kdecore/kernel/kstandarddirs.cpp	2008-11-12 18:31:44.000000000 +0100
+++ kdelibs-4.1.72.kstandarddirs/kdecore/kernel/kstandarddirs.cpp	2008-11-12 18:38:40.000000000 +0100
@@ -1002,7 +1002,9 @@
                  pit != prefixList->end();
                  ++pit)
             {
-	        if((*pit)!=installprefix||installdir.isEmpty())
+                // "exe" never has a custom install path, and the check triggers
+                // a false positive due to the libexecdir patch
+	        if((*pit)!=installprefix||installdir.isEmpty()||!strcmp("exe", type))
 	        {
                     for (QStringList::ConstIterator it = dirs.constBegin();
                          it != dirs.constEnd(); ++it)
@@ -1016,6 +1018,11 @@
                         if ((local || testdir.exists()) && !candidates.contains(path))
                             candidates.append(path);
                     }
+                    // special-case "config" (forward porting Chris Cheney's
+                    // hack) - we want /etc/kde after the local config paths
+                    // and before the ones in /usr (including kde-profile)
+                    if (local && !strcmp("config", type))
+                       candidates.append("/etc/kde/");
                     local = false;
                 }
 	        else

kdelibs-4.1.72-no-cache-kdeglobals-paths.patch:

--- NEW FILE kdelibs-4.1.72-no-cache-kdeglobals-paths.patch ---
diff -Naur kdelibs-4.1.72/kdecore/config/kconfig.cpp kdelibs-4.1.72.no-cache-kdeglobals-path/kdecore/config/kconfig.cpp
--- kdelibs-4.1.72/kdecore/config/kconfig.cpp	2008-10-23 01:05:09.000000000 +0200
+++ kdelibs-4.1.72.no-cache-kdeglobals-path/kdecore/config/kconfig.cpp	2008-11-10 17:38:33.000000000 +0100
@@ -61,12 +61,6 @@
 {
     sGlobalFileName = componentData.dirs()->saveLocation("config") +
                           QString::fromLatin1("kdeglobals");
-    if (wantGlobals()) {
-        const KStandardDirs *const dirs = componentData.dirs();
-        foreach(const QString& dir, dirs->findAllResources("config", QLatin1String("kdeglobals")) +
-                                    dirs->findAllResources("config", QLatin1String("system.kdeglobals")))
-            globalFiles.push_front(dir);
-    }
     const QString etc_kderc =
 #ifdef Q_WS_WIN
         QFile::decodeName( qgetenv("WINDIR") + "/kde4rc" );
@@ -76,15 +70,11 @@
     KEntryMap tmp;
     // first entry is always /etc/kderc or empty if cannot read
     if (KStandardDirs::checkAccess(etc_kderc, R_OK)) {
-        if (!globalFiles.contains(etc_kderc))
-            globalFiles.push_front(etc_kderc);
-
         if (!mappingsRegistered) {
             KSharedPtr<KConfigBackend> backend = KConfigBackend::create(componentData, etc_kderc, QLatin1String("INI"));
             backend->parseConfig( "en_US", tmp, KConfigBackend::ParseDefaults);
         }
     } else {
-        globalFiles.push_front(QString());
         mappingsRegistered = true;
     }
 
@@ -461,10 +451,31 @@
 
 void KConfigPrivate::parseGlobalFiles()
 {
+    QStringList globalFiles;
+
+    if (wantGlobals()) {
+        const KStandardDirs *const dirs = componentData.dirs();
+        foreach(const QString& dir, dirs->findAllResources("config", QLatin1String("kdeglobals")) +
+                                    dirs->findAllResources("config", QLatin1String("system.kdeglobals")))
+            globalFiles.push_front(dir);
+    }
+    const QString etc_kderc =
+#ifdef Q_WS_WIN
+        QFile::decodeName( QByteArray(::getenv("WINDIR")) + "\\kde4rc" );
+#else
+        QLatin1String("/etc/kde4rc");
+#endif
+    KEntryMap tmp;
+    // first entry is always /etc/kderc or empty if cannot read
+    if (KStandardDirs::checkAccess(etc_kderc, R_OK)) {
+        if (!globalFiles.contains(etc_kderc))
+            globalFiles.push_front(etc_kderc);
+    } else {
+        globalFiles.push_front(QString());
+    }
+
 //    qDebug() << "parsing global files" << globalFiles;
 
-    // TODO: can we cache the values in etc_kderc / other global files
-    //       on a per-application basis?
     const QByteArray utf8Locale = locale.toUtf8();
     foreach(const QString& file, globalFiles) {
         KConfigBackend::ParseOptions parseOpts = KConfigBackend::ParseGlobal|KConfigBackend::ParseExpansions;
diff -Naur kdelibs-4.1.72/kdecore/config/kconfig_p.h kdelibs-4.1.72.no-cache-kdeglobals-path/kdecore/config/kconfig_p.h
--- kdelibs-4.1.72/kdecore/config/kconfig_p.h	2008-06-03 11:34:54.000000000 +0200
+++ kdelibs-4.1.72.no-cache-kdeglobals-path/kdecore/config/kconfig_p.h	2008-11-10 17:38:33.000000000 +0100
@@ -86,7 +86,6 @@
 
     KEntryMap entryMap;
     QString backendType;
-    QStringList globalFiles;
     QStack<QString> extraFiles;
 
     QString locale;

kdelibs-4.1.72-policykit-workaround.patch:

--- NEW FILE kdelibs-4.1.72-policykit-workaround.patch ---
diff -Naur kdelibs-4.1.72.policykit/solid/solid/backends/hal/halstorageaccess.cpp kdelibs-4.1.72/solid/solid/backends/hal/halstorageaccess.cpp
--- kdelibs-4.1.72.policykit/solid/solid/backends/hal/halstorageaccess.cpp	2008-11-04 18:13:11.000000000 +0100
+++ kdelibs-4.1.72/solid/solid/backends/hal/halstorageaccess.cpp	2008-11-10 18:45:41.000000000 +0100
@@ -17,6 +17,8 @@
 
 */
 
+#include <config-prefix.h> // for LIBEXEC_INSTALL_DIR
+
 #include "halstorageaccess.h"
 
 #include "halfstabhandling.h"
@@ -172,11 +174,21 @@
 {
     // TODO: Better error reporting here
     if (m_setupInProgress) {
+	if (error.name() == "org.freedesktop.Hal.Device.PermissionDeniedByPolicy") {
+            if (callPrivilegedMount())
+              return;
+            // if we fail to run kdesu, fall through and emit the original PermissionDeniedByPolicy error
+        }
         m_setupInProgress = false;
         emit setupDone(Solid::UnauthorizedOperation,
                        error.name()+": "+error.message(),
                        m_device->udi());
     } else if (m_teardownInProgress) {
+	if (error.name() == "org.freedesktop.Hal.Device.PermissionDeniedByPolicy") {
+            if (callPrivilegedUnmount())
+              return;
+            // if we fail to run kdesu, fall through and emit the original PermissionDeniedByPolicy error
+        }
         m_teardownInProgress = false;
         emit teardownDone(Solid::UnauthorizedOperation,
                           error.name()+": "+error.message(),
@@ -294,8 +306,9 @@
 #else
     QString uid="uid=";
 #endif
-    if (halOptions.contains(uid)) {
-        options << uid+QString::number(::getuid());
+    if (halOptions.contains(uid) &&
+       (fstype == "vfat" || fstype == "iso9660" || fstype == "hfs" || fstype == "udf")) {
+            options << uid+QString::number(::getuid());
     }
 
 #ifdef Q_OS_FREEBSD
@@ -333,6 +346,59 @@
                               SLOT(slotDBusError(const QDBusError &)));
 }
 
+bool Solid::Backends::Hal::StorageAccess::callPrivilegedMount()
+{
+    QString udi = m_device->udi();
+    QString options;
+    QStringList halOptions = m_device->property("volume.mount.valid_options").toStringList();
+    QString fstype = m_device->property("volume.fstype").toString();
+
+    if (halOptions.contains("uid=")
+        && (fstype == "vfat" || fstype == "iso9660" || fstype == "hfs" || fstype == "udf")) {
+        options = "uid="+QString::number(::getuid());
+    }
+
+    m_process = new QProcess(this);
+
+    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
+            this, SLOT(slotProcessFinished(int, QProcess::ExitStatus)));
+
+    m_process->start(LIBEXEC_INSTALL_DIR "/kdesu", QStringList() << "-d" << "-t"
+        << "--noignorebutton" << "-c"
+        << QString::fromLatin1("dbus-send  --system --print-reply --dest=org.freedesktop.Hal %1 "
+                               "org.freedesktop.Hal.Device.Volume.Mount string: string: "
+                               "array:string:%2").arg(udi).arg(options));
+
+    if (m_process->waitForStarted()) {
+        return true;
+    } else {
+        delete m_process;
+        return false;
+    }
+}
+
+bool Solid::Backends::Hal::StorageAccess::callPrivilegedUnmount()
+{
+    QString udi = m_device->udi();
+
+    m_process = new QProcess(this);
+
+    connect(m_process, SIGNAL(finished(int, QProcess::ExitStatus)),
+            this, SLOT(slotProcessFinished(int, QProcess::ExitStatus)));
+
+    m_process->start(LIBEXEC_INSTALL_DIR "/kdesu", QStringList() << "-d" << "-t"
+        << "--noignorebutton" << "-c"
+        << QString::fromLatin1("dbus-send  --system --print-reply --dest=org.freedesktop.Hal %1 "
+                               "org.freedesktop.Hal.Device.Volume.Unmount array:string:").arg(udi));
+
+    if (m_process->waitForStarted()) {
+        return true;
+    } else {
+        delete m_process;
+        return false;
+    }
+}
+
 bool StorageAccess::callHalVolumeUnmount()
 {
     QDBusConnection c = QDBusConnection::systemBus();
diff -Naur kdelibs-4.1.72.policykit/solid/solid/backends/hal/halstorageaccess.h kdelibs-4.1.72/solid/solid/backends/hal/halstorageaccess.h
--- kdelibs-4.1.72.policykit/solid/solid/backends/hal/halstorageaccess.h	2008-05-21 13:07:38.000000000 +0200
+++ kdelibs-4.1.72/solid/solid/backends/hal/halstorageaccess.h	2008-11-10 18:45:01.000000000 +0100
@@ -69,6 +69,9 @@
     bool callSystemMount();
     bool callSystemUnmount();
 
+    bool callPrivilegedMount();
+    bool callPrivilegedUnmount();
+
     bool requestPassphrase();
     void callCryptoSetup(const QString &passphrase);
     bool callCryptoTeardown();

kdelibs-4.1.82-kde149705.patch:

--- NEW FILE kdelibs-4.1.82-kde149705.patch ---
diff -Naurw kdelibs-4.1.82/kdeui/icons/kicontheme.cpp kdelibs-4.1.82.kde149705/kdeui/icons/kicontheme.cpp
--- kdelibs-4.1.82/kdeui/icons/kicontheme.cpp	2008-10-23 01:05:04.000000000 +0200
+++ kdelibs-4.1.82.kde149705/kdeui/icons/kicontheme.cpp	2008-12-09 14:15:14.000000000 +0100
@@ -516,7 +516,7 @@
         return *_theme;
 
     KConfigGroup cg(KGlobal::config(), "Icons");
-    *_theme = cg.readEntry("Theme", defaultThemeName());
+    *_theme = cg.readEntry("Theme4", cg.readEntry("Theme", defaultThemeName()));
     if ( *_theme == QLatin1String("hicolor") ) *_theme = defaultThemeName();
 /*    if (_theme->isEmpty())
     {
diff -Naurw kdelibs-4.1.82/kdeui/kernel/kglobalsettings.cpp kdelibs-4.1.82.kde149705/kdeui/kernel/kglobalsettings.cpp
--- kdelibs-4.1.82/kdeui/kernel/kglobalsettings.cpp	2008-11-28 16:40:11.000000000 +0100
+++ kdelibs-4.1.82.kde149705/kdeui/kernel/kglobalsettings.cpp	2008-12-09 14:17:51.000000000 +0100
@@ -831,7 +831,7 @@
     if (kde_overrideStyle.isEmpty()) {
         const QString &defaultStyle = KStyle::defaultStyle();
         const KConfigGroup pConfig(KGlobal::config(), "General");
-        const QString &styleStr = pConfig.readEntry("widgetStyle", defaultStyle);
+        const QString &styleStr = pConfig.readEntry("widgetStyle4", pConfig.readEntry("widgetStyle", defaultStyle));
 
         if (styleStr.isEmpty() ||
                 // check whether we already use the correct style to return then
diff -Naurw kdelibs-4.1.82/kutils/kdeglobals.kcfg kdelibs-4.1.82.kde149705/kutils/kdeglobals.kcfg
--- kdelibs-4.1.82/kutils/kdeglobals.kcfg	2008-05-21 13:08:56.000000000 +0200
+++ kdelibs-4.1.82.kde149705/kutils/kdeglobals.kcfg	2008-12-09 14:15:14.000000000 +0100
@@ -24,6 +24,10 @@
    <whatsthis>The name of the widget style, for example "keramik" or "plastik". Without quotes.</whatsthis>
    <default>keramik</default>
   </entry>
+  <entry key="widgetStyle4" type="String" >
+   <label>Widget style to use for KDE 4</label>
+   <whatsthis>The name of the widget style, for example "oxygen". Without quotes. Defaults to widgetStyle.</whatsthis>
+  </entry>
   <entry key="windowBackground" type="String" />
   <entry key="windowForeground" type="String" />
   <entry key="UseSystemBell" type="Bool" >

kdelibs-4.1.96-AllowExternalPaths.patch:

--- NEW FILE kdelibs-4.1.96-AllowExternalPaths.patch ---
diff -up kdelibs-4.1.96/plasma/package.cpp.orig kdelibs-4.1.96/plasma/package.cpp
--- kdelibs-4.1.96/plasma/package.cpp.orig	2009-01-06 18:27:56.000000000 +0100
+++ kdelibs-4.1.96/plasma/package.cpp	2009-01-16 14:42:39.000000000 +0100
@@ -139,6 +139,10 @@ QString Package::filePath(const char *fi
     }
 
     if (QFile::exists(path)) {
+        if (d->structure->allowExternalPaths()) {
+            return path;
+        }
+
         // ensure that we don't return files outside of our base path
         // due to symlink or ../ games
         QDir dir(path);
@@ -171,6 +175,10 @@ QStringList Package::entryList(const cha
     QDir dir(d->basePath + d->structure->contentsPrefix() + path);
 
     if (dir.exists()) {
+        if (d->structure->allowExternalPaths()) {
+            return dir.entryList(QDir::Files | QDir::Readable);
+        }
+
         // ensure that we don't return files outside of our base path
         // due to symlink or ../ games
         QString canonicalized = dir.canonicalPath();
diff -up kdelibs-4.1.96/plasma/packagestructure.cpp.orig kdelibs-4.1.96/plasma/packagestructure.cpp
--- kdelibs-4.1.96/plasma/packagestructure.cpp.orig	2009-01-16 14:41:56.000000000 +0100
+++ kdelibs-4.1.96/plasma/packagestructure.cpp	2009-01-16 14:42:39.000000000 +0100
@@ -58,17 +58,19 @@ class ContentStructure
         QString path;
         QString name;
         QStringList mimetypes;
-        bool directory;
-        bool required;
+        bool directory : 1;
+        bool required : 1;
 };
 
 class PackageStructurePrivate
 {
 public:
     PackageStructurePrivate()
-        : metadata(0)
+        : metadata(0),
+          externalPaths(false)
     {
     }
+
     ~PackageStructurePrivate()
     {
         delete metadata;
@@ -76,6 +78,8 @@ public:
 
     void createPackageMetadata(const QString &path);
 
+    static QHash<QString, PackageStructure::Ptr> structures;
+
     QString type;
     QString path;
     QString contentsPrefix;
@@ -83,8 +87,8 @@ public:
     QString servicePrefix;
     QMap<QByteArray, ContentStructure> contents;
     QStringList mimetypes;
-    static QHash<QString, PackageStructure::Ptr> structures;
     PackageMetadata *metadata;
+    bool externalPaths;
  };
 
 QHash<QString, PackageStructure::Ptr> PackageStructurePrivate::structures;
@@ -487,6 +491,16 @@ PackageMetadata PackageStructure::metada
     return *d->metadata;
 }
 
+bool PackageStructure::allowExternalPaths() const
+{
+    return d->externalPaths;
+}
+
+void PackageStructure::setAllowExternalPaths(bool allow)
+{
+    d->externalPaths = allow;
+}
+
 } // Plasma namespace
 
 #include "packagestructure.moc"
diff -up kdelibs-4.1.96/plasma/packagestructure.h.orig kdelibs-4.1.96/plasma/packagestructure.h
--- kdelibs-4.1.96/plasma/packagestructure.h.orig	2009-01-16 14:19:12.000000000 +0100
+++ kdelibs-4.1.96/plasma/packagestructure.h	2009-01-16 14:42:39.000000000 +0100
@@ -278,6 +278,12 @@ public:
       */
     virtual PackageMetadata metadata();
 
+    /**
+     * @return true if paths/symlinks outside the package itself should be followed.
+     * By default this is set to false for security reasons.
+     */
+    bool allowExternalPaths() const;
+
 Q_SIGNALS:
     /**
      * Emitted when the new widget browser process completes.
@@ -286,6 +292,13 @@ Q_SIGNALS:
 
 protected:
     /**
+     * Sets whether or not external paths/symlinks can be followed by a package
+     * @arg allow true if paths/symlinks outside of the package should be followed,
+     *             false if they should be rejected.
+     */
+    void setAllowExternalPaths(bool allow);
+
+    /**
      * Sets the prefix that all the contents in this package should
      * appear under. This defaults to "contents/" and is added automatically
      * between the base path and the entries as defined by the package

kdelibs-4.1.96-cmake.patch:

--- NEW FILE kdelibs-4.1.96-cmake.patch ---
diff -up kdelibs-4.1.96/cmake/modules/FindKdepimLibs.cmake.orig kdelibs-4.1.96/cmake/modules/FindKdepimLibs.cmake
--- kdelibs-4.1.96/cmake/modules/FindKdepimLibs.cmake.orig	2009-01-08 22:14:13.000000000 +0100
+++ kdelibs-4.1.96/cmake/modules/FindKdepimLibs.cmake	2009-01-08 22:14:59.000000000 +0100
@@ -64,9 +64,13 @@
 # See kdepimlibs/CMakeLists.txt and kdepimlibs/KdepimLibsConfig.cmake.in 
 # for details. Alex
 
-
+set(KDEPIMLIBS_VERSION 4.2.0)
+set(_KdepimLibsConfig_INSTALL_DIR ${LIB_INSTALL_DIR}/KdepimLibs-${KDEPIMLIBS_VERSION}/cmake)
+if(KDE4_USE_COMMON_CMAKE_PACKAGE_CONFIG_DIR)
+   set(_KdepimLibsConfig_INSTALL_DIR ${LIB_INSTALL_DIR}/cmake/KdepimLibs-${KDEPIMLIBS_VERSION} )
+endif(KDE4_USE_COMMON_CMAKE_PACKAGE_CONFIG_DIR)
 set(_KdepimLibs_FIND_QUIETLY  ${KdepimLibs_FIND_QUIETLY})
-find_package(KdepimLibs ${KdepimLibs_FIND_VERSION} QUIET NO_MODULE PATHS ${KDE4_LIB_DIR}/KdepimLibs/cmake )
+find_package(KdepimLibs ${KdepimLibs_FIND_VERSION} QUIET NO_MODULE PATHS ${_KdepimLibsConfig_INSTALL_DIR} )
 set(KdepimLibs_FIND_QUIETLY ${_KdepimLibs_FIND_QUIETLY})
 
 include(FindPackageHandleStandardArgs)
diff -up kdelibs-4.1.96/cmake/modules/FindKDE4Workspace.cmake.orig kdelibs-4.1.96/cmake/modules/FindKDE4Workspace.cmake
--- kdelibs-4.1.96/cmake/modules/FindKDE4Workspace.cmake.orig	2009-01-10 21:53:41.000000000 +0100
+++ kdelibs-4.1.96/cmake/modules/FindKDE4Workspace.cmake	2009-01-10 21:54:03.000000000 +0100
@@ -62,8 +62,14 @@
 # for details. Alex
 
 
+set(KDE4WORKSPACE_VERSION 4.2.0)
+set(_KdeWorkspaceConfig_INSTALL_DIR ${LIB_INSTALL_DIR}/KDE4Workspace-${KDE4WORKSPACE_VERSION}/cmake)
+if(KDE4_USE_COMMON_CMAKE_PACKAGE_CONFIG_DIR)
+   set(_KdeWorkspaceConfig_INSTALL_DIR ${LIB_INSTALL_DIR}/cmake/KDE4Workspace-${KDE4WORKSPACE_VERSION} )
+endif(KDE4_USE_COMMON_CMAKE_PACKAGE_CONFIG_DIR)
+
 set(_KDE4Workspace_FIND_QUIETLY  ${KDE4Workspace_FIND_QUIETLY})
-find_package(KDE4Workspace QUIET NO_MODULE PATHS ${KDE4_LIB_DIR}/KDE4Workspace/cmake )
+find_package(KDE4Workspace QUIET NO_MODULE PATHS ${_KdeWorkspaceConfig_INSTALL_DIR} )
 set(KDE4Workspace_FIND_QUIETLY ${_KDE4Workspace_FIND_QUIETLY})
 
 include(FindPackageHandleStandardArgs)

kdelibs-4.1.96-parallel_devel.patch:

--- NEW FILE kdelibs-4.1.96-parallel_devel.patch ---
diff -up kdelibs-4.1.96/doc/api/doxygen-preprocess-kcfg.sh.parallel_devel kdelibs-4.1.96/doc/api/doxygen-preprocess-kcfg.sh
--- kdelibs-4.1.96/doc/api/doxygen-preprocess-kcfg.sh.parallel_devel	2008-05-21 13:07:26.000000000 +0200
+++ kdelibs-4.1.96/doc/api/doxygen-preprocess-kcfg.sh	2009-01-07 22:04:13.000000000 +0100
@@ -2,9 +2,9 @@
 # Generates and cleans KConfigXT source code during a API dox build
 #
 
-kcfg_compiler="`kde4-config --prefix`/bin/kconfig_compiler"
+kcfg_compiler="`kde4-config --prefix`/bin/kconfig_compiler4"
 if test -z "$kcfg_compiler"; then
-	echo "kconfig_compiler not found!"
+	echo "kconfig_compiler4 not found!"
 	exit 1;
 fi
 
diff -up kdelibs-4.1.96/kdecore/kconfig_compiler/checkkcfg.pl.parallel_devel kdelibs-4.1.96/kdecore/kconfig_compiler/checkkcfg.pl
--- kdelibs-4.1.96/kdecore/kconfig_compiler/checkkcfg.pl.parallel_devel	2008-05-21 13:09:13.000000000 +0200
+++ kdelibs-4.1.96/kdecore/kconfig_compiler/checkkcfg.pl	2009-01-07 22:04:13.000000000 +0100
@@ -15,12 +15,12 @@ $file_cpp = "$filebase.cpp";
 
 $kcfgc = $file . "c";
 
-$cmd = "./kconfig_compiler $file $kcfgc";
+$cmd = "./kconfig_compiler4 $file $kcfgc";
 
 #print "CMD $cmd\n";
 
 if ( system( $cmd ) != 0 ) {
-  print STDERR "Unable to run kconfig_compiler\n";
+  print STDERR "Unable to run kconfig_compiler4\n";
   exit 1;
 }
 
diff -up kdelibs-4.1.96/kdecore/kconfig_compiler/CMakeLists.txt.parallel_devel kdelibs-4.1.96/kdecore/kconfig_compiler/CMakeLists.txt
--- kdelibs-4.1.96/kdecore/kconfig_compiler/CMakeLists.txt.parallel_devel	2009-01-06 18:27:49.000000000 +0100
+++ kdelibs-4.1.96/kdecore/kconfig_compiler/CMakeLists.txt	2009-01-07 22:44:57.000000000 +0100
@@ -8,13 +8,13 @@ add_subdirectory( example )
 set(kconfig_compiler_SRCS kconfig_compiler.cpp)
 
 
-kde4_add_executable(kconfig_compiler NOGUI RUN_UNINSTALLED ${kconfig_compiler_SRCS})
+kde4_add_executable(kconfig_compiler4 NOGUI RUN_UNINSTALLED ${kconfig_compiler_SRCS})
 
-target_link_libraries(kconfig_compiler  ${QT_QTCORE_LIBRARY} ${QT_QTXML_LIBRARY} )
+target_link_libraries(kconfig_compiler4  ${QT_QTCORE_LIBRARY} ${QT_QTXML_LIBRARY} )
 
 # "export" this target too so we can use the LOCATION property of the imported target in
 # FindKDE4Internal.cmake to get the full path to the installed executable instead of using FIND_PROGRAM(), Alex
-install(TARGETS kconfig_compiler EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS} )
+install(TARGETS kconfig_compiler4 EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS} )
 
 
 ########### install files ###############
diff -up kdelibs-4.1.96/kdeui/tests/kconfig_compiler/CMakeLists.txt.parallel_devel kdelibs-4.1.96/kdeui/tests/kconfig_compiler/CMakeLists.txt
--- kdelibs-4.1.96/kdeui/tests/kconfig_compiler/CMakeLists.txt.parallel_devel	2008-05-21 13:08:30.000000000 +0200
+++ kdelibs-4.1.96/kdeui/tests/kconfig_compiler/CMakeLists.txt	2009-01-07 22:04:13.000000000 +0100
@@ -9,7 +9,7 @@ macro(GEN_KCFG_TEST_SOURCE _testName _sr
    add_custom_command(
       OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.cpp ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h
       COMMAND ${KDE4_KCFGC_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc
-      DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc kconfig_compiler)
+      DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfg ${CMAKE_CURRENT_SOURCE_DIR}/${_testName}.kcfgc kconfig_compiler4)
 
 #   set_source_files_properties(${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h PROPERTIES GENERATED TRUE)
    qt4_generate_moc(${CMAKE_CURRENT_BINARY_DIR}/${_testName}.h ${CMAKE_CURRENT_BINARY_DIR}/${_testName}.moc )
diff -up kdelibs-4.1.96/kdewidgets/CMakeLists.txt.parallel_devel kdelibs-4.1.96/kdewidgets/CMakeLists.txt
--- kdelibs-4.1.96/kdewidgets/CMakeLists.txt.parallel_devel	2009-01-06 18:27:44.000000000 +0100
+++ kdelibs-4.1.96/kdewidgets/CMakeLists.txt	2009-01-07 22:46:30.000000000 +0100
@@ -14,24 +14,24 @@ include_directories( 
 set(makekdewidgets_SRCS makekdewidgets.cpp )
 
 
-kde4_add_executable(makekdewidgets NOGUI RUN_UNINSTALLED ${makekdewidgets_SRCS})
+kde4_add_executable(makekdewidgets4 NOGUI RUN_UNINSTALLED ${makekdewidgets_SRCS})
 
-target_link_libraries(makekdewidgets  ${KDE4_KDECORE_LIBS} )
+target_link_libraries(makekdewidgets4  ${KDE4_KDECORE_LIBS} )
 
 # "export" this target too so we can use the LOCATION property of the imported target in
 # FindKDE4Internal.cmake to get the full path to the installed executable instead of using FIND_PROGRAM(), Alex
-install(TARGETS makekdewidgets  EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS} )
+install(TARGETS makekdewidgets4  EXPORT kdelibsToolsTargets ${INSTALL_TARGETS_DEFAULT_ARGS} )
 
 
 ########### next target ###############
 
 
 # get the name of the generated wrapper script (which sets up LD_LIBRARY_PATH)
-get_target_property(MAKEKDEWIDGETS_EXECUTABLE makekdewidgets WRAPPER_SCRIPT)
+get_target_property(MAKEKDEWIDGETS_EXECUTABLE makekdewidgets4 WRAPPER_SCRIPT)
 
 add_custom_command(OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/kdewidgets.cpp
   COMMAND "${MAKEKDEWIDGETS_EXECUTABLE}" -o ${CMAKE_CURRENT_BINARY_DIR}/kdewidgets.cpp ${CMAKE_CURRENT_SOURCE_DIR}/kde.widgets
-  MAIN_DEPENDENCY kde.widgets DEPENDS makekdewidgets)
+  MAIN_DEPENDENCY kde.widgets DEPENDS makekdewidgets4)
 
 set(kdewidgets_PART_SRCS
    classpreviews.cpp


Index: .cvsignore
===================================================================
RCS file: /cvs/pkgs/rpms/kdelibs/F-10/.cvsignore,v
retrieving revision 1.61
retrieving revision 1.62
diff -u -r1.61 -r1.62
--- .cvsignore	7 Jan 2009 12:27:19 -0000	1.61
+++ .cvsignore	23 Jan 2009 18:59:58 -0000	1.62
@@ -1 +1 @@
-kdelibs-4.1.4.tar.bz2
+kdelibs-4.2.0.tar.bz2


Index: kde4.csh
===================================================================
RCS file: /cvs/pkgs/rpms/kdelibs/F-10/kde4.csh,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- kde4.csh	1 Dec 2007 19:43:21 -0000	1.2
+++ kde4.csh	23 Jan 2009 18:59:58 -0000	1.3
@@ -10,9 +10,16 @@
    if ( "$PRELINKING" == "yes" )  then
      if ( ! $?KDE_IS_PRELINKED ) setenv KDE_IS_PRELINKED 1
    endif
+   unset PRELINKING
 endif
 
-if ( ! $?QT_PLUGIN_PATH ) then
-  set KDE4_LIBDIR = `/bin/rpm --eval %\{\?_kde4_libdir\}%\{\!\?_kde4_libdir:%\{_libdir\}\}`
-  setenv QT_PLUGIN_PATH ${KDE4_LIBDIR}/kde4/plugins
+# handled in startkde, but this sets for other DE's too
+set KDE4_QTPLUGINS=`kde4-config --path qtplugins`
+if ( $?QT_PLUGIN_PATH ) then
+  if ( "$QT_PLUGIN_PATH" !~ *"${KDE4_QTPLUGINS}"* ) then
+    setenv QT_PLUGIN_PATH ${QT_PLUGIN_PATH}:${KDE4_QTPLUGINS}
+  endif 
+else
+  setenv QT_PLUGIN_PATH ${KDE4_QTPLUGINS} 
 endif
+unset KDE4_QTPLUGINS


Index: kde4.sh
===================================================================
RCS file: /cvs/pkgs/rpms/kdelibs/F-10/kde4.sh,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- kde4.sh	1 Dec 2007 19:43:21 -0000	1.2
+++ kde4.sh	23 Jan 2009 18:59:58 -0000	1.3
@@ -5,13 +5,19 @@
 [ -z "$KDEDIRS" ] && KDEDIRS="/usr" && export KDEDIRS
 
 ## When/if using prelinking, avoids (some) use of kdeinit
-if [ -f /etc/sysconfig/prelink ]; then
-  if [ `grep '^PRELINKING=yes' /etc/sysconfig/prelink` ] ; then
-    [ -z "$KDE_IS_PRELINKED" ] && KDE_IS_PRELINKED=1 && export KDE_IS_PRELINKED
-  fi
+if [ -z "$KDE_IS_PRELINKED" ] ; then
+  grep -qs '^PRELINKING=yes' /etc/sysconfig/prelink && \
+  KDE_IS_PRELINKED=1 && export KDE_IS_PRELINKED
 fi
 
-if [ -z "$QT_PLUGIN_PATH" ]; then
-  KDE4_LIBDIR=`/bin/rpm --eval '%{?_kde4_libdir}%{!?_kde4_libdir:%{_libdir}}' 2>/dev/null`
-  QT_PLUGIN_PATH=${KDE4_LIBDIR}/kde4/plugins && export QT_PLUGIN_PATH
+
+# handled in startkde, but this sets for other DE's too
+if [ -n "$QT_PLUGIN_PATH" ] ; then
+  if ! echo "$QT_PLUGIN_PATH" | grep -qw `kde4-config --path qtplugins` ; then
+    QT_PLUGIN_PATH="$QT_PLUGIN_PATH:`kde4-config --path qtplugins`"
+  fi
+else
+  QT_PLUGIN_PATH="`kde4-config --path qtplugins`"
 fi
+export QT_PLUGIN_PATH
+


Index: kdelibs.spec
===================================================================
RCS file: /cvs/pkgs/rpms/kdelibs/F-10/kdelibs.spec,v
retrieving revision 1.395
retrieving revision 1.396
diff -u -r1.395 -r1.396
--- kdelibs.spec	8 Jan 2009 05:00:14 -0000	1.395
+++ kdelibs.spec	23 Jan 2009 18:59:58 -0000	1.396
@@ -1,8 +1,6 @@
-%define _default_patch_fuzz 2
-
 Summary: K Desktop Environment 4 - Libraries
-Version: 4.1.4
-Release: 2%{?dist}
+Version: 4.2.0
+Release: 1%{?dist}
 
 %if 0%{?fedora} > 8
 Name: kdelibs
@@ -29,13 +27,14 @@
 %endif
 
 BuildRequires: kde4-macros(api) >= 2
-BuildRequires: kde-filesystem >= 4
+BuildRequires: kde-filesystem >= 4-23
+# used in kde.(sh|csh)
+Requires: coreutils grep
+# dbus-launch needed here? don't think so, but be safe and keep 
+# for now -- Rex
 Requires: dbus-x11
 Requires: hicolor-icon-theme
-# kdebase-runtime not *strictly* required here, but how better to pull
-# it in?  comps only?
-#Requires: kdebase-runtime
-Requires: kde-filesystem >= 4
+Requires: kde-filesystem >= 4-23
 Requires: kde-settings
 %{?_kde4_macros_api:Requires: kde4-macros(api) = %{_kde4_macros_api} }
 Requires: shared-mime-info
@@ -45,15 +44,16 @@
 %if 0%{?fedora} >= 9
 Requires: hunspell
 %endif
-Requires: soprano >= 2.1
+Requires: phonon >= 4.2.96
+Requires: soprano >= 2.1.64
 
 Source1: kde4.sh
 Source2: kde4.csh
 
 # make -devel packages parallel-installable
-Patch0: kdelibs-4.1.0-parallel_devel.patch
+Patch0: kdelibs-4.1.96-parallel_devel.patch
 # fix kde#149705
-Patch2: kdelibs-3.95.0-kde149705.patch
+Patch2: kdelibs-4.1.82-kde149705.patch
 # Hunspell support for K3Spell
 # http://fedoraproject.org/wiki/Releases/FeatureDictionary
 # http://bugs.kde.org/show_bug.cgi?id=154561
@@ -67,20 +67,23 @@
 Patch9: kdelibs-4.0.2-branding.patch
 # don't cache kdeglobals paths because they change after profile directories
 # are loaded from kde4rc
-Patch10: kdelibs-4.0.2-no-cache-kdeglobals-paths.patch
-# workarounds for policykit and NTFS
-Patch11: kdelibs-4.1.4-policykit-workaround.patch
+Patch10: kdelibs-4.1.72-no-cache-kdeglobals-paths.patch
+# workaround for policykit
+Patch11: kdelibs-4.1.72-policykit-workaround.patch
 Patch12: kdelibs-4.1.0-xdg-menu.patch
 # patch KStandardDirs to use %{_libexecdir}/kde4 instead of %{_libdir}/kde4/libexec
 Patch14: kdelibs-4.0.85-libexecdir.patch
 # kstandarddirs changes: search /etc/kde, find /usr/libexec/kde4
-Patch18: kdelibs-4.1.0-kstandarddirs.patch
-Patch20: kdelibs-4.1.1-cmake.patch
-
-## upstream patches
+Patch18: kdelibs-4.1.72-kstandarddirs.patch
+Patch20: kdelibs-4.1.70-cmake.patch
+Patch22: kdelibs-4.1.96-cmake.patch
+
+# upstream
+# 4.3 branch
+Patch101: kdelibs-4.1.96-AllowExternalPaths.patch
 
 BuildRequires: qt4-devel >= 4.4.0
-Requires: qt4 >= %{_qt4_version} 
+Requires: qt4 >= %{_qt4_version}
 Requires: xdg-utils
 Requires(post): /sbin/ldconfig xdg-utils
 Requires(postun): /sbin/ldconfig xdg-utils
@@ -93,7 +96,7 @@
 BuildRequires: automoc
 BuildRequires: avahi-devel
 BuildRequires: bzip2-devel
-BuildRequires: cmake
+BuildRequires: cmake >= 2.6.2-3
 BuildRequires: cups-devel cups
 BuildRequires: enchant-devel
 BuildRequires: gamin-devel
@@ -111,15 +114,13 @@
 BuildRequires: OpenEXR-devel
 BuildRequires: openssl-devel
 BuildRequires: pcre-devel
-# work around circular dependency from phonon-devel pulling in phonon-backend-xine
-BuildRequires: phonon-backend-gstreamer
-BuildRequires: phonon-devel >= 4.2
+BuildRequires: phonon-devel >= 4.2.96
 BuildRequires: shared-mime-info
-BuildRequires: soprano-devel >= 2.1
-BuildRequires: strigi-devel >= 0.5.7
+BuildRequires: soprano-devel >= 2.1.64
+BuildRequires: strigi-devel >= 0.6.3
 BuildRequires: zlib-devel
 BuildRequires: libutempter-devel
-# extra X deps (seemingly needed and/or checked-for by most kde4 buildscripts) 
+# extra X deps (seemingly needed and/or checked-for by most kde4 buildscripts)
 %define x_deps libXcomposite-devel libXdamage-devel libxkbfile-devel libXpm-devel libXScrnSaver-devel libXtst-devel libXv-devel libXxf86misc-devel
 %{?x_deps:BuildRequires: %{x_deps}}
 BuildRequires: openssh-clients
@@ -145,16 +146,18 @@
 %package devel
 Group: Development/Libraries
 Summary: Header files for compiling KDE 4 applications
+Provides: plasma-devel = %{version}-%{release}
 Requires: %{name} = %{?epoch:%{epoch}:}%{version}-%{release}
 %if "%{name}" != "kdelibs4"
 Obsoletes: kdelibs4-devel < %{version}-%{release}
 Provides:  kdelibs4-devel = %{version}-%{release}
 %endif
+Requires: cmake >= 2.6.2-3
 Requires: automoc
 Requires: qt4-devel
 Requires: openssl-devel
-Requires: phonon-devel >= 4.2
-Requires: strigi-devel
+Requires: phonon-devel >= 4.2.96
+Requires: strigi-devel >= 0.6.3
 Requires: bzip2-devel gamin-devel libacl-devel zlib-devel libutempter-devel
 %{?x_deps:Requires: %{x_deps}}
 %description devel
@@ -196,18 +199,20 @@
 %patch9 -p1 -b .branding
 sed -i -e "s|@@VERSION_RELEASE@@|%{version}-%{release}|" kio/kio/kprotocolmanager.cpp
 %patch10 -p1 -b .no-cache-kdeglobals-paths
-%patch11 -p1 -b .policykit
+#%patch11 -p1 -b .policykit
 %patch12 -p1 -b .Administration-menu
 %patch14 -p1 -b .libexecdir
 %patch18 -p1 -b .kstandarddirs
-%patch20 -p1 -b .cmake
-
-## upstream patches
+%patch20 -p1 -b .xxcmake
+%patch22 -p1 -b .kdepimlibs-cmake
 
+# upstream patches
+%patch101 -p1 -b .AllowExternalPaths
 
 %build
+
 mkdir -p %{_target_platform}
-pushd %{_target_platform} 
+pushd %{_target_platform}
 %{cmake_kde4} -DKDE_DISTRIBUTION_TEXT="%{version}-%{release} Fedora" ..
 popd
 
@@ -226,7 +231,7 @@
 rm -rf %{buildroot}
 
 %if 0%{?rest}
-make install DESTDIR=%{buildroot} -C %{_target_platform}
+make install/fast DESTDIR=%{buildroot} -C %{_target_platform}
 
 # see also use-of/patching of XDG_MENU_PREFIX in kdebase/kde-settings
 mv %{buildroot}%{_kde4_sysconfdir}/xdg/menus/applications.menu \
@@ -283,7 +288,7 @@
 xdg-icon-resource forceupdate --theme hicolor 2> /dev/null || :
 xdg-desktop-menu forceupdate 2> /dev/null || :
 
-%postun 
+%postun
 /sbin/ldconfig ||:
 xdg-icon-resource forceupdate --theme hicolor 2> /dev/null || :
 xdg-desktop-menu forceupdate 2> /dev/null || :
@@ -313,8 +318,9 @@
 %{_kde4_datadir}/mime/packages/*
 %{_kde4_sharedir}/kde4/services/*
 %{_kde4_sharedir}/kde4/servicetypes/*
-%{_kde4_sharedir}/icons/hicolor/*/actions/presence_*
+%{_kde4_sharedir}/icons/hicolor/*/actions/*
 %{_kde4_docdir}/HTML/en/sonnet/
+%{_kde4_docdir}/HTML/en/kioslave/
 %{_kde4_libdir}/lib*.so.*
 %{_kde4_libdir}/libkdeinit4_*.so
 %dir %{_kde4_libdir}/kde4/
@@ -363,23 +369,99 @@
 
 
 %changelog
-* Thu Jan 08 2009 Kevin Kofler <Kevin at tigcc.ticalc.org> 4.1.4-2
-- restore AWOL NTFS workaround yet again
+* Thu Jan 22 2009 Than Ngo <than at redhat.com> - 4.2.0-1
+- 4.2.0
 
-* Wed Jan  7 2009 Lukáš Tinkl <ltinkl at redhat.com> 4.1.4-1
-- KDE 4.1.4
+* Fri Jan 16 2009 Than Ngo <than at redhat.com> - 4.1.96-9
+- drop kdelibs-4.1.85-plasma-default-wallpaper.patch, it's not needed
+  since new plasma allows to define default wallpaper, new kde-setting
+  is required
+- backport fix from trunk to allow symlinks in wallpaper theme
 
-* Mon Dec 08 2008 Kevin Kofler <Kevin at tigcc.ticalc.org> 4.1.3-4
-- restore NTFS workaround which accidentally got dropped in the 4.1.3 update
+* Fri Jan 16 2009 Kevin Kofler <Kevin at tigcc.ticalc.org> - 4.1.96-8
+- rebuild for new OpenSSL
 
-* Thu Nov 20 2008 Rex Dieter <rdieter at fedoraproject.org> 4.1.3-3
-- unmess Utilities menu (kdebug:161117)
+* Mon Jan 12 2009 Rex Dieter <rdieter at fedoraproject.org> - 4.1.96-7
+- Slight speedup to profile.d/kde.sh (#465370)
+- (Build)Req: strigi(-devel) >= 0.6.3
 
-* Fri Nov 07 2008 Rex Dieter <rdieter at fedoraproject.org> 4.1.3-2
-- backport http_cache_cleaner fix (kdebug:172182)
+* Mon Jan 12 2009 Than Ngo <than at redhat.com> - 4.1.96-6
+- fix a crash (appearing in KSMServer)
+
+* Sat Jan 10 2009 Than Ngo <than at redhat.com> - 4.1.96-5
+- kdeworkspace cmake files in correct place
+
+* Fri Jan 09 2009 Rex Dieter <rdieter at fedoraproject.org> - 4.1.96-4
+- bump min deps (cmake, kde-filesystem, phonon)
+- kde.(sh|csh): cleanup QT_PLUGIN_PATH handling
+- Requires: coreutils grep
+
+* Fri Jan 09 2009 Than Ngo <than at redhat.com> - 4.1.96-3
+- BR soprano >= 2.1.64
+
+* Thu Jan 08 2009 Than Ngo <than at redhat.com> - 4.1.96-2
+- kdepim cmake files in correct place
+
+* Wed Jan 07 2009 Than Ngo <than at redhat.com> - 4.1.96-1
+- 4.2rc1
+
+* Fri Dec 19 2008 Kevin Kofler <Kevin at tigcc.ticalc.org> 4.1.85-6
+- add plasma-default-wallpaper libplasma patch from kdebase-workspace-4.1
+
+* Tue Dec 16 2008 Rex Dieter <rdieter at fedoraproject.org> 4.1.85-5
+- respun tarball, integrates kde-l10n-systemsettings patch
+
+* Tue Dec 16 2008 Than Ngo <than at redhat.com> - 4.1.85-4
+- add missing ENTITY systemsettings in pt, that fixes kde-l10
+  build breakage
 
-* Tue Nov  4 2008 Lukáš Tinkl <ltinkl at redhat.com> 4.1.3-1
-- KDE 4.1.3
+* Mon Dec 15 2008 Than Ngo <than at redhat.com> - 4.1.85-3
+- add missing ENTITY systemsettings in ru/gl/es/pt, that fixes kde-l10
+  build breakage
+- rename suffix .xxcmake to avoid install .cmake
+
+* Sun Dec 14 2008 Kevin Kofler <Kevin at tigcc.ticalc.org> - 4.1.85-2
+- tweak parallel_devel patch to get a -L flag for the symlink directory
+
+* Thu Dec 11 2008 Than Ngo <than at redhat.com> -  4.1.85-1
+- 4.2beta2
+
+* Tue Dec 09 2008 Lorenzo Villani <lvillani at binaryhelix.net> - 6:4.1.82-2
+- rebase parallel devel patch and kde149705 patch
+
+* Mon Dec 08 2008 Lorenzo Villani <lvillani at binaryhelix.net> - 6:4.1.82-1
+- 4.1.82
+
+* Tue Nov 25 2008 Kevin Kofler <Kevin at tigcc.ticalc.org> 4.1.80-5
+- remove workaround BR on phonon-backend-gstreamer, it's ineffective since
+  phonon now explicitly Requires: phonon-backend-xine and the dependency is no
+  longer circular anyway
+- update parallel_devel patch
+- fix minimum strigi version (only 0.5.9 needed)
+
+* Tue Nov 25 2008 Than Ngo <than at redhat.com> 4.1.80-4
+- respin
+
+* Thu Nov 20 2008 Rex Dieter <rdieter at fedoraproject.org> 4.1.80-3
+- -devel: Provides: plasma-devel
+
+* Thu Nov 20 2008 Than Ngo <than at redhat.com> 4.1.80-2
+- merged
+
+* Thu Nov 20 2008 Lorenzo Villani <lvillani at binaryhelix.net> - 6:4.1.80-1
+- 4.1.80
+- BR strigi 0.60
+- BR cmake 2.6
+- make install/fast
+- rebase policykit patch
+- rebase cmake patch
+- rebase a couple of patches and drop _default_patch_fuzz 2
+
+* Wed Nov 12 2008 Than Ngo <than at redhat.com> 4.1.3-1
+- 4.1.3
+
+* Fri Nov 07 2008 Rex Dieter <rdieter at fedoraproject.org> 4.1.2-6
+- backport http_cache_cleaner fix (kdebug:172182)
 
 * Wed Oct 15 2008 Lukáš Tinkl <ltinkl at redhat.com> 4.1.2-5
 - backport fix for faulty window resizing (kdebug:172042)
@@ -831,7 +913,7 @@
 
 * Wed Jun 27 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.91.0-1
 - kde-3.91.0
-- CMAKE_BUILD_TYPE=debug 
+- CMAKE_BUILD_TYPE=debug
 
 * Sat Jun 23 2007 Rex Dieter <rdieter[AT]fedoraproject.org> 3.90.1-3
 - specfile cleanup (%%prefix issues mostly)


Index: sources
===================================================================
RCS file: /cvs/pkgs/rpms/kdelibs/F-10/sources,v
retrieving revision 1.73
retrieving revision 1.74
diff -u -r1.73 -r1.74
--- sources	7 Jan 2009 12:27:19 -0000	1.73
+++ sources	23 Jan 2009 18:59:58 -0000	1.74
@@ -1 +1 @@
-ffdb0340a72aaf06a0b98f354c0c59ef  kdelibs-4.1.4.tar.bz2
+4ea13b88463125026a7f71937075bcec  kdelibs-4.2.0.tar.bz2


--- kdelibs-3.95.0-kde149705.patch DELETED ---


--- kdelibs-4.0.2-no-cache-kdeglobals-paths.patch DELETED ---


--- kdelibs-4.1.0-kstandarddirs.patch DELETED ---


--- kdelibs-4.1.0-parallel_devel.patch DELETED ---


--- kdelibs-4.1.1-cmake.patch DELETED ---


--- kdelibs-4.1.4-policykit-workaround.patch DELETED ---




More information about the fedora-extras-commits mailing list
diff -up kdelibs-4.1.96/cmake/modules/FindKDE4Internal.cmake.parallel_devel kdelibs-4.1.96/cmake/modules/FindKDE4Internal.cmake
--- kdelibs-4.1.96/cmake/modules/FindKDE4Internal.cmake.parallel_devel	2009-01-07 01:13:55.000000000 +0100
+++ kdelibs-4.1.96/cmake/modules/FindKDE4Internal.cmake	2009-01-07 22:42:22.000000000 +0100
@@ -15,10 +15,10 @@
 # The following variables are defined for the various tools required to
 # compile KDE software:
 #
-#  KDE4_KCFGC_EXECUTABLE    - the kconfig_compiler executable
+#  KDE4_KCFGC_EXECUTABLE    - the kconfig_compiler4 executable
 #  KDE4_AUTOMOC_EXECUTABLE  - the kde4automoc executable, deprecated, use AUTOMOC4_EXECUTABLE instead
 #  KDE4_MEINPROC_EXECUTABLE - the meinproc4 executable
-#  KDE4_MAKEKDEWIDGETS_EXECUTABLE - the makekdewidgets executable
+#  KDE4_MAKEKDEWIDGETS_EXECUTABLE - the makekdewidgets4 executable
 #
 # The following variables point to the location of the KDE libraries,
 # but shouldn't be used directly:
@@ -131,7 +131,7 @@
 #    Use optional GENERATE_MOC to generate moc if you use signals in your kcfg files.
 #
 #  KDE4_ADD_WIDGET_FILES (SRCS_VAR file1.widgets ... fileN.widgets)
 #    Use this to add widget description files for the makekdewidgets code generator
 #    for Qt Designer plugins.
 #
 #  KDE4_CREATE_FINAL_FILES (filename_CXX filename_C file1 ... fileN)
@@ -370,23 +370,23 @@ if (_kdeBootStrapping)
    if (WIN32)
       set(LIBRARY_OUTPUT_PATH            ${EXECUTABLE_OUTPUT_PATH} )
       # CMAKE_CFG_INTDIR is the output subdirectory created e.g. by XCode and MSVC
-      set(KDE4_KCFGC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler )
+      set(KDE4_KCFGC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler4 )
 
       set(KDE4_MEINPROC_EXECUTABLE       ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc4 )
-      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets )
+      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets4 )
    else (WIN32)
       set(LIBRARY_OUTPUT_PATH            ${CMAKE_BINARY_DIR}/lib )
-      set(KDE4_KCFGC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler.shell )
+      set(KDE4_KCFGC_EXECUTABLE          ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/kconfig_compiler4.shell )
 
       set(KDE4_MEINPROC_EXECUTABLE       ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/meinproc4.shell )
-      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets.shell )
+      set(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${EXECUTABLE_OUTPUT_PATH}/${CMAKE_CFG_INTDIR}/makekdewidgets4.shell )
    endif (WIN32)
 
    set(KDE4_LIB_DIR ${LIBRARY_OUTPUT_PATH}/${CMAKE_CFG_INTDIR})
 
    # when building kdelibs, make the kcfg rules depend on the binaries...
-   set( _KDE4_KCONFIG_COMPILER_DEP kconfig_compiler)
-   set( _KDE4_MAKEKDEWIDGETS_DEP makekdewidgets)
+   set( _KDE4_KCONFIG_COMPILER_DEP kconfig_compiler4)
+   set( _KDE4_MAKEKDEWIDGETS_DEP makekdewidgets4)
    set( _KDE4_MEINPROC_EXECUTABLE_DEP meinproc4)
 
    set(KDE4_INSTALLED_VERSION_OK TRUE)
@@ -488,7 +488,8 @@ else (_kdeBootStrapping)
 
    # KDE4_LIB_INSTALL_DIR and KDE4_INCLUDE_INSTALL_DIR are set in KDELibsDependencies.cmake,
    # use them to set the KDE4_LIB_DIR and KDE4_INCLUDE_DIR "public interface" variables
-   set(KDE4_LIB_DIR ${KDE4_LIB_INSTALL_DIR} )
+   set(KDE4_LIB_DIR ${KDE4_LIB_INSTALL_DIR}/kde4/devel )
+   link_directories("${KDE4_LIB_DIR}")
    set(KDE4_INCLUDE_DIR ${KDE4_INCLUDE_INSTALL_DIR} )
 
 
@@ -501,12 +502,12 @@ else (_kdeBootStrapping)
 
    # get the build CONFIGURATIONS which were exported in this file, and use just the first
    # of them to get the location of the installed executables
-   get_target_property(_importedConfigurations  ${KDE4_TARGET_PREFIX}kconfig_compiler IMPORTED_CONFIGURATIONS )
+   get_target_property(_importedConfigurations  ${KDE4_TARGET_PREFIX}kconfig_compiler4 IMPORTED_CONFIGURATIONS )
    list(GET _importedConfigurations 0 _firstConfig)
 
-   get_target_property(KDE4_KCFGC_EXECUTABLE          ${KDE4_TARGET_PREFIX}kconfig_compiler LOCATION_${firstConfig})
+   get_target_property(KDE4_KCFGC_EXECUTABLE          ${KDE4_TARGET_PREFIX}kconfig_compiler4 LOCATION_${firstConfig})
    get_target_property(KDE4_MEINPROC_EXECUTABLE       ${KDE4_TARGET_PREFIX}meinproc4        LOCATION_${firstConfig})
-   get_target_property(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${KDE4_TARGET_PREFIX}makekdewidgets   LOCATION_${firstConfig})
+   get_target_property(KDE4_MAKEKDEWIDGETS_EXECUTABLE ${KDE4_TARGET_PREFIX}makekdewidgets4   LOCATION_${firstConfig})
 
    # allow searching cmake modules in all given kde install locations (KDEDIRS based)
    execute_process(COMMAND "${KDE4_KDECONFIG_EXECUTABLE}" --path data OUTPUT_VARIABLE _data_DIR ERROR_QUIET OUTPUT_STRIP_TRAILING_WHITESPACE)
@@ -738,7 +739,8 @@ set(CMAKE_SYSTEM_INCLUDE_PATH ${CMAKE_SY
 set(CMAKE_SYSTEM_PROGRAM_PATH ${CMAKE_SYSTEM_PROGRAM_PATH}
                               "${KDE4_BIN_INSTALL_DIR}" )
 
-set(CMAKE_SYSTEM_LIBRARY_PATH ${CMAKE_SYSTEM_LIBRARY_PATH} 
+set(CMAKE_SYSTEM_LIBRARY_PATH "${KDE4_LIB_INSTALL_DIR}/kde4/devel"
+                              ${CMAKE_SYSTEM_LIBRARY_PATH}
                               "${KDE4_LIB_INSTALL_DIR}" )
 
 # under Windows dlls may be also installed in bin/
@@ -1121,9 +1123,9 @@ macro (KDE4_PRINT_RESULTS)
    endif (NOT _kdeBootStrapping)
 
    if(KDE4_KCFGC_EXECUTABLE)
-      message(STATUS "Found the KDE4 kconfig_compiler preprocessor: ${KDE4_KCFGC_EXECUTABLE}")
+      message(STATUS "Found the KDE4 kconfig_compiler4 preprocessor: ${KDE4_KCFGC_EXECUTABLE}")
    else(KDE4_KCFGC_EXECUTABLE)
-      message(STATUS "Didn't find the KDE4 kconfig_compiler preprocessor")
+      message(STATUS "Didn't find the KDE4 kconfig_compiler4 preprocessor")
    endif(KDE4_KCFGC_EXECUTABLE)
 
    if(AUTOMOC4_EXECUTABLE)
@@ -1142,7 +1145,7 @@ if (KDE4Internal_FIND_REQUIRED AND NOT K
    endif (NOT KDE4_INSTALLED_VERSION_OK)
 
    if (NOT KDE4_KCFGC_EXECUTABLE)
-     message(FATAL_ERROR "ERROR: could not detect a usable kconfig_compiler")
+     message(FATAL_ERROR "ERROR: could not detect a usable kconfig_compiler4")
    endif (NOT KDE4_KCFGC_EXECUTABLE)
 
    message(FATAL_ERROR "ERROR: could NOT find everything required for compiling KDE 4 programs")
@@ -131,7 +131,7 @@
 #
 #  KDE4_ADD_WIDGET_FILES (SRCS_VAR file1.widgets ... fileN.widgets)
-#    Use this to add widget description files for the makekdewidgets code generator
+#    Use this to add widget description files for the makekdewidgets4 code generator
 #    for Qt Designer plugins.
 #